@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "convertvariablesjobtest.h"
@@ -44,7 +31,7 @@ void ConvertVariablesJobTest::shouldCanStart()
     job.setText(QStringLiteral("bla"));
     QVERIFY(!job.canStart());
     MessageComposer::ComposerViewBase b;
-    MessageComposer::ComposerViewInterface *interface = new MessageComposer::ComposerViewInterface(&b);
+    auto *interface = new MessageComposer::ComposerViewInterface(&b);
     job.setComposerViewInterface(interface);
     QVERIFY(job.canStart());
 }
@@ -54,7 +41,7 @@ void ConvertVariablesJobTest::shouldConvertVariables()
     QFETCH(QString, original);
     QFETCH(QString, expected);
     MessageComposer::ComposerViewBase b;
-    MessageComposer::ComposerViewInterface *interface = new MessageComposer::ComposerViewInterface(&b);
+    auto *interface = new MessageComposer::ComposerViewInterface(&b);
     MessageComposer::ConvertSnippetVariablesJob job;
     job.setComposerViewInterface(interface);
     b.setSubject(QStringLiteral("Subject!!!!"));
