@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 #include "attachmentupdatejobtest.h"
 #include <attachment/attachmentupdatejob.h>
@@ -36,7 +25,7 @@ void AttachmentUpdateJobTest::shouldHaveDefaultValue()
 {
     MessageCore::AttachmentPart::Ptr origPart = MessageCore::AttachmentPart::Ptr(new MessageCore::AttachmentPart);
 
-    MessageCore::AttachmentUpdateJob *job = new MessageCore::AttachmentUpdateJob(origPart, this);
+    auto *job = new MessageCore::AttachmentUpdateJob(origPart, this);
     QCOMPARE(origPart, job->originalPart());
     QVERIFY(!job->updatedPart());
     delete job;
@@ -60,7 +49,7 @@ void AttachmentUpdateJobTest::shouldUpdateAttachment()
     origPart->setData(data);
     origPart->setUrl(url);
 
-    MessageCore::AttachmentUpdateJob *job = new MessageCore::AttachmentUpdateJob(origPart, this);
+    auto *job = new MessageCore::AttachmentUpdateJob(origPart, this);
 
     VERIFYEXEC(job);
     QVERIFY(origPart->size() != job->updatedPart()->size());
@@ -87,7 +76,7 @@ void AttachmentUpdateJobTest::shouldHaveSameNameDescriptionAfterUpdate()
     origPart->setData(data);
     origPart->setUrl(url);
 
-    MessageCore::AttachmentUpdateJob *job = new MessageCore::AttachmentUpdateJob(origPart, this);
+    auto *job = new MessageCore::AttachmentUpdateJob(origPart, this);
 
     VERIFYEXEC(job);
     QCOMPARE(origPart->name(), job->updatedPart()->name());
@@ -115,7 +104,7 @@ void AttachmentUpdateJobTest::shouldHaveSameCryptoSignStatusAfterUpdate()
     origPart->setSigned(true);
     origPart->setEncrypted(true);
 
-    MessageCore::AttachmentUpdateJob *job = new MessageCore::AttachmentUpdateJob(origPart, this);
+    auto *job = new MessageCore::AttachmentUpdateJob(origPart, this);
 
     VERIFYEXEC(job);
     QCOMPARE(origPart->isSigned(), job->updatedPart()->isSigned());
@@ -142,7 +131,7 @@ void AttachmentUpdateJobTest::shouldHaveSameEncodingAfterUpdate()
     origPart->setSigned(true);
     origPart->setEncrypted(true);
 
-    MessageCore::AttachmentUpdateJob *job = new MessageCore::AttachmentUpdateJob(origPart, this);
+    auto *job = new MessageCore::AttachmentUpdateJob(origPart, this);
 
     VERIFYEXEC(job);
     QCOMPARE(origPart->encoding(), job->updatedPart()->encoding());
@@ -168,7 +157,7 @@ void AttachmentUpdateJobTest::shouldHaveSameMimetypeAfterUpdate()
     origPart->setSigned(true);
     origPart->setEncrypted(true);
 
-    MessageCore::AttachmentUpdateJob *job = new MessageCore::AttachmentUpdateJob(origPart, this);
+    auto *job = new MessageCore::AttachmentUpdateJob(origPart, this);
 
     VERIFYEXEC(job);
     QCOMPARE(origPart->mimeType(), job->updatedPart()->mimeType());
@@ -188,7 +177,7 @@ void AttachmentUpdateJobTest::shouldNotUpdateWhenUrlIsEmpty()
     origPart->setEncoding(KMime::Headers::CE7Bit);
     origPart->setData(data);
 
-    MessageCore::AttachmentUpdateJob *job = new MessageCore::AttachmentUpdateJob(origPart, this);
+    auto *job = new MessageCore::AttachmentUpdateJob(origPart, this);
     job->exec();
     QVERIFY(!job->updatedPart());
 }
@@ -214,7 +203,7 @@ void AttachmentUpdateJobTest::shouldHaveSameInlineStatus()
     origPart->setEncrypted(true);
     origPart->setInline(true);
 
-    MessageCore::AttachmentUpdateJob *job = new MessageCore::AttachmentUpdateJob(origPart, this);
+    auto *job = new MessageCore::AttachmentUpdateJob(origPart, this);
 
     VERIFYEXEC(job);
     QCOMPARE(origPart->isInline(), job->updatedPart()->isInline());
