@@ -1,20 +1,8 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free softhisare; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Softhisare Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Softhisare
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
@@ -128,7 +116,7 @@ static inline const QFont &cachedFont(const Theme::ContentItem *ci, const Item *
         return cachedFont(ci);
     }
 
-    const MessageItem *mi = static_cast<const MessageItem *>(i);
+    const auto *mi = static_cast<const MessageItem *>(i);
     const bool bold = ci->isBold() || mi->isBold();
     const bool italic = ci->isItalic() || mi->isItalic();
     return (!bold && !italic) ? sFontCache[Normal]
@@ -562,7 +550,7 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
 
     // Set background color of control if necessary
     if (item->type() == Item::Message) {
-        MessageItem *msgItem = static_cast< MessageItem * >(item);
+        auto *msgItem = static_cast< MessageItem * >(item);
         if (msgItem->backgroundColor().isValid()) {
             opt.backgroundBrush = QBrush(msgItem->backgroundColor());
         }
@@ -865,6 +853,9 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
             case Theme::ContentItem::Size:
                 paint_right_aligned_elided_text(item->formattedSize(), ci, painter, l, top, r, layoutDir, font);
                 break;
+            case Theme::ContentItem::Folder:
+                paint_right_aligned_elided_text(item->folder(), ci, painter, l, top, r, layoutDir, font);
+                break;
             case Theme::ContentItem::GroupHeaderLabel:
                 if (groupHeaderItem) {
                     paint_right_aligned_elided_text(groupHeaderItem->label(), ci, painter, l, top, r, layoutDir, font);
@@ -1029,6 +1020,9 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
             case Theme::ContentItem::Size:
                 paint_left_aligned_elided_text(item->formattedSize(), ci, painter, l, top, r, layoutDir, font);
                 break;
+            case Theme::ContentItem::Folder:
+                paint_left_aligned_elided_text(item->folder(), ci, painter, l, top, r, layoutDir, font);
+                break;
             case Theme::ContentItem::GroupHeaderLabel:
                 if (groupHeaderItem) {
                     paint_left_aligned_elided_text(groupHeaderItem->label(), ci, painter, l, top, r, layoutDir, font);
@@ -1283,6 +1277,9 @@ bool ThemeDelegate::hitTest(const QPoint &viewportPoint, bool exact)
             case Theme::ContentItem::Size:
                 compute_bounding_rect_for_right_aligned_elided_text(mHitItem->formattedSize(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
                 break;
+            case Theme::ContentItem::Folder:
+                compute_bounding_rect_for_right_aligned_elided_text(mHitItem->folder(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
+                break;
             case Theme::ContentItem::GroupHeaderLabel:
                 if (groupHeaderItem) {
                     compute_bounding_rect_for_right_aligned_elided_text(groupHeaderItem->label(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
@@ -1428,6 +1425,9 @@ bool ThemeDelegate::hitTest(const QPoint &viewportPoint, bool exact)
             case Theme::ContentItem::Size:
                 compute_bounding_rect_for_left_aligned_elided_text(mHitItem->formattedSize(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
                 break;
+            case Theme::ContentItem::Folder:
+                compute_bounding_rect_for_left_aligned_elided_text(mHitItem->folder(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
+                break;
             case Theme::ContentItem::GroupHeaderLabel:
                 if (groupHeaderItem) {
                     compute_bounding_rect_for_left_aligned_elided_text(groupHeaderItem->label(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
