@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "searchlinestatus.h"
@@ -47,7 +35,7 @@ SearchLineStatus::SearchLineStatus(QWidget *parent)
     setClearButtonEnabled(true);
     initializeActions();
     createMenuSearch();
-    QAction *act = findChild<QAction *>(QLatin1String(qLineEditclearButtonActionNameC));
+    auto *act = findChild<QAction *>(QLatin1String(qLineEditclearButtonActionNameC));
     if (act) {
         connect(act, &QAction::triggered, this, &SearchLineStatus::slotClear);
     } else {
@@ -67,7 +55,7 @@ void SearchLineStatus::keyPressEvent(QKeyEvent *e)
         } else {
             Q_EMIT forceLostFocus();
         }
-    } else if (e->key() == Qt::Key_Q && (e->modifiers().testFlag(Qt::ShiftModifier) &&  e->modifiers().testFlag(Qt::AltModifier))) {
+    } else if (e->key() == Qt::Key_Q && (e->modifiers().testFlag(Qt::ShiftModifier) && e->modifiers().testFlag(Qt::AltModifier))) {
         mLockAction->trigger();
     } else {
         QLineEdit::keyPressEvent(e);
@@ -164,7 +152,7 @@ void SearchLineStatus::clearFilterAction()
 
 void SearchLineStatus::createFilterAction(const QIcon &icon, const QString &text, int value)
 {
-    QAction *act = new QAction(icon, text, this);
+    auto *act = new QAction(icon, text, this);
     act->setCheckable(true);
     act->setData(value);
     mFilterMenu->addAction(act);
@@ -193,7 +181,7 @@ void SearchLineStatus::createMenuSearch()
 {
     mFilterMenu = new QMenu(this);
     mFilterMenu->setObjectName(QStringLiteral("filtermenu"));
-    QWidgetAction *clearWidgetAction = new QWidgetAction(mFilterMenu);
+    auto *clearWidgetAction = new QWidgetAction(mFilterMenu);
     QPushButton *clearFilterButton = new QPushButton(i18n("Clear Filter"), mFilterMenu);
     connect(clearFilterButton, &QPushButton::clicked, this, &SearchLineStatus::clearFilterButtonClicked);
 
@@ -247,7 +235,7 @@ void SearchLineStatus::createMenuSearch()
 void SearchLineStatus::createFilterByAction()
 {
     mFilterMenu->addSeparator();
-    QActionGroup *grp = new QActionGroup(mFilterMenu);
+    auto *grp = new QActionGroup(mFilterMenu);
 
     mSearchEveryWhereAction = new QAction(i18n("Full Message"), mFilterMenu);
     mSearchEveryWhereAction->setCheckable(true);
