@@ -1,20 +1,8 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
@@ -23,7 +11,7 @@
 
 #include <QTabWidget>
 
-class KLineEdit;
+class QLineEdit;
 class KTextEdit;
 
 namespace MessageList {
@@ -50,7 +38,7 @@ protected:
     * Returns the editor for the name of the OptionSet.
     * Derived classes are responsable of filling this UI element and reading back data from it.
     */
-    KLineEdit *nameEdit() const;
+    QLineEdit *nameEdit() const;
 
     /**
     * Returns the editor for the description of the OptionSet.
@@ -66,7 +54,7 @@ protected Q_SLOTS:
     virtual void slotNameEditTextEdited(const QString &newName) = 0;
 
 private:
-    KLineEdit *mNameEdit = nullptr;                        ///< The editor for the OptionSet name
+    QLineEdit *mNameEdit = nullptr;                        ///< The editor for the OptionSet name
     KTextEdit *mDescriptionEdit = nullptr;                 ///< The editor for the OptionSet description
 };
 } // namespace Utils
