@@ -8,7 +8,6 @@
 #include "dkimutil.h"
 #include "messageviewer_dkimcheckerdebug.h"
 
-#include <QStringList>
 using namespace MessageViewer;
 
 DKIMInfo::DKIMInfo()
@@ -81,7 +80,7 @@ bool DKIMInfo::parseDKIM(const QString &header)
         mVersion = 1;
     }
     if (mQuery.isEmpty()) {
-        mQuery = QLatin1String("dns/txt");
+        mQuery = QStringLiteral("dns/txt");
     }
     if (mAgentOrUserIdentifier.isEmpty()) {
         mAgentOrUserIdentifier = QLatin1Char('@') + mDomain;
