@@ -5,22 +5,9 @@
   Copyright (c) James Ashton - Sydney University - June 1990. //krazy:exclude=copyright
 
   Additions for KDE:
-  Copyright (c) 2004 Jakob Schröter <js@camaya.net>
+  SPDX-FileCopyrightText: 2004 Jakob Schröter <js@camaya.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kxface.h"
@@ -103,45 +90,45 @@ QString KXFace::fromImage(const QImage &image)
     for (int i = 0; i < len; ++i) {
         switch (tmp[i].toLatin1()) {
         case '1':
-            tmp[i] = '8';
+            tmp[i] = QLatin1Char('8');
             break;
         case '2':
-            tmp[i] = '4';
+            tmp[i] = QLatin1Char('4');
             break;
         case '3':
-            tmp[i] = 'c';
+            tmp[i] = QLatin1Char('c');
             break;
         case '4':
-            tmp[i] = '2';
+            tmp[i] = QLatin1Char('2');
             break;
         case '5':
-            tmp[i] = 'a';
+            tmp[i] = QLatin1Char('a');
             break;
         case '7':
-            tmp[i] = 'e';
+            tmp[i] = QLatin1Char('e');
             break;
         case '8':
-            tmp[i] = '1';
+            tmp[i] = QLatin1Char('1');
             break;
         case 'A':
         case 'a':
-            tmp[i] = '5';
+            tmp[i] = QLatin1Char('5');
             break;
         case 'B':
         case 'b':
-            tmp[i] = 'd';
+            tmp[i] = QLatin1Char('d');
             break;
         case 'C':
         case 'c':
-            tmp[i] = '3';
+            tmp[i] = QLatin1Char('3');
             break;
         case 'D':
         case 'd':
-            tmp[i] = 'b';
+            tmp[i] = QLatin1Char('b');
             break;
         case 'E':
         case 'e':
-            tmp[i] = '7';
+            tmp[i] = QLatin1Char('7');
             break;
         }
         if (i % 2) {
