@@ -6,7 +6,7 @@
     SPDX-FileCopyrightText: 2002-2003, 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
     SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
 
-    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "urlhandlermanager.h"
@@ -236,6 +236,7 @@ URLHandlerManager::URLHandlerManager()
     registerHandler(new ShowAuditLogURLHandler());
     registerHandler(new InternalImageURLHandler);
     registerHandler(new KRunURLHandler());
+    registerHandler(new EmbeddedImageURLHandler());
 }
 
 URLHandlerManager::~URLHandlerManager()
@@ -563,7 +564,7 @@ QString MailToURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *) con
 static QString searchFullEmailByUid(const QString &uid)
 {
     QString fullEmail;
-    Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+    auto *job = new Akonadi::ContactSearchJob();
     job->setLimit(1);
     job->setQuery(Akonadi::ContactSearchJob::ContactUid, uid,
                   Akonadi::ContactSearchJob::ExactMatch);
@@ -773,8 +774,8 @@ bool AttachmentURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window) co
             QFile::ReadOwner | QFile::WriteOwner | QFile::ReadUser | QFile::ReadGroup
             | QFile::ReadOther);
         const QString icon = Util::iconPathForContent(node, KIconLoader::Small);
-        QDrag *drag = new QDrag(window->viewer());
-        QMimeData *mimeData = new QMimeData();
+        auto *drag = new QDrag(window->viewer());
+        auto *mimeData = new QMimeData();
         mimeData->setUrls(QList<QUrl>() << tUrl);
         drag->setMimeData(mimeData);
         if (!icon.isEmpty()) {
@@ -918,3 +919,16 @@ bool KRunURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
         return false;
     }
 }
+
+bool EmbeddedImageURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window) const
+{
+    Q_UNUSED(url);
+    Q_UNUSED(window);
+    return false;
+}
+
+bool EmbeddedImageURLHandler::willHandleDrag(const QUrl &url, ViewerPrivate *window) const
+{
+    Q_UNUSED(window);
+    return url.scheme() == QLatin1String("cid");
+}
